# fx-crash-sig

Get crash signature from Firefox crash trace

Take crash trace and:

1. Use [tecken](https://github.com/mozilla-services/tecken) symbolication to symbolicate crash trace

2. use [socorro-siggen](https://github.com/willkg/socorro-siggen) to get crash signature
